@@ -8,8 +8,7 @@ struct saved_cwd
   };
 
 int save_cwd (struct saved_cwd *cwd);
-int restore_cwd (const struct saved_cwd *cwd, const char *dest,
-		 const char *from);
+int restore_cwd (const struct saved_cwd *cwd);
 void free_cwd (struct saved_cwd *cwd);
 
 #endif /* SAVE_CWD_H */
