@@ -37,7 +37,6 @@
 #include "ftw.h"
 #include "hash.h"
 #include "human.h"
-#include "mmap-stack.h"
 #include "quote.h"
 #include "quotearg.h"
 #include "same.h"
@@ -316,12 +315,13 @@ process_file (const char *file, const struct stat *sb, int file_type,
 	      struct FTW *info)
 {
   uintmax_t size;
-  uintmax_t size_including_subdirs;
-  uintmax_t size_to_propagate_to_parent;
+  uintmax_t size_to_print;
   static int first_call = 1;
   static size_t prev_level;
   static size_t n_alloc;
-  static uintmax_t *sum;
+  static uintmax_t *sum_ent;
+  static uintmax_t *sum_subdir;
+  int print = 1;
 
   /* Always define info->skip before returning.  */
   info->skip = excluded_filename (exclude, file + info->base);
@@ -373,6 +373,7 @@ process_file (const char *file, const struct stat *sb, int file_type,
 	 We still have to update prev_level and maybe propagate
 	 some sums up the hierarchy.  */
       size = 0;
+      print = 0;
     }
   else
     {
@@ -384,7 +385,8 @@ process_file (const char *file, const struct stat *sb, int file_type,
   if (first_call)
     {
       n_alloc = info->level + 10;
-      sum = XCALLOC (uintmax_t, n_alloc);
+      sum_ent = XCALLOC (uintmax_t, n_alloc);
+      sum_subdir = XCALLOC (uintmax_t, n_alloc);
     }
   else
     {
@@ -396,11 +398,12 @@ process_file (const char *file, const struct stat *sb, int file_type,
       if (n_alloc <= (size_t) info->level)
 	{
 	  n_alloc = info->level * 2;
-	  sum = XREALLOC (sum, uintmax_t, n_alloc);
+	  sum_ent = XREALLOC (sum_ent, uintmax_t, n_alloc);
+	  sum_subdir = XREALLOC (sum_subdir, uintmax_t, n_alloc);
 	}
     }
 
-  size_to_propagate_to_parent = size_including_subdirs = size;
+  size_to_print = size;
 
   if (! first_call)
     {
@@ -416,7 +419,7 @@ process_file (const char *file, const struct stat *sb, int file_type,
 	     e.g., from 1 to 10.  */
 	  int i;
 	  for (i = prev_level + 1; i <= info->level; i++)
-	    sum[i] = 0;
+	    sum_ent[i] = sum_subdir[i] = 0;
 	}
       else /* info->level < prev_level */
 	{
@@ -427,20 +430,23 @@ process_file (const char *file, const struct stat *sb, int file_type,
 	     Here, the current level is always one smaller than the
 	     previous one.  */
 	  assert ((size_t) info->level == prev_level - 1);
-	  size_to_propagate_to_parent = size_including_subdirs
-	    = size + sum[prev_level];
+	  size_to_print += sum_ent[prev_level];
+	  if (!opt_separate_dirs)
+	    size_to_print += sum_subdir[prev_level];
+	  sum_subdir[info->level] += (sum_ent[prev_level]
+				      + sum_subdir[prev_level]);
 	}
     }
 
-  if (opt_separate_dirs)
-    size_to_propagate_to_parent = 0;
-
   prev_level = info->level;
   first_call = 0;
 
-  sum[info->level] += size_to_propagate_to_parent;
+  /* Let the size of a directory entry contribute to the total for the
+     containing directory, unless --separate-dirs (-S) is specified.  */
+  if ( ! (opt_separate_dirs && IS_FTW_DIR_TYPE (file_type)))
+    sum_ent[info->level] += size;
 
-  /* Even if this directory was unreadable or we couldn't chdir into it,
+  /* Even if this directory is unreadable or we can't chdir into it,
      do let its size contribute to the total, ... */
   tot_size += size;
 
@@ -449,12 +455,18 @@ process_file (const char *file, const struct stat *sb, int file_type,
   if (file_type == FTW_DNR || file_type == FTW_DCH)
     return 0;
 
+  /* If we're not counting an entry, e.g., because it's a hard link
+     to a file we've already counted (and --count-links), then don't
+     print a line for it.  */
+  if (!print)
+    return 0;
+
   /* FIXME: This looks suspiciously like it could be simplified.  */
   if ((IS_FTW_DIR_TYPE (file_type) &&
 		     (info->level <= max_depth || info->level == 0))
       || ((opt_all && info->level <= max_depth) || info->level == 0))
     {
-      print_only_size (size_including_subdirs);
+      print_only_size (size_to_print);
       fputc ('\t', stdout);
       if (arg_length)
 	{
@@ -494,8 +506,7 @@ is_symlink_to_dir (char const *file)
    FTW_FLAGS controls how nftw works.
    Return nonzero upon error.  */
 
-static void du_files (char **files, int ftw_flags) ATTRIBUTE_NORETURN;
-static void
+static int
 du_files (char **files, int ftw_flags)
 {
   int fail = 0;
@@ -542,7 +553,7 @@ du_files (char **files, int ftw_flags)
   if (print_totals)
     print_size (tot_size, _("total"));
 
-  exit (fail || G_fail ? EXIT_FAILURE : EXIT_SUCCESS);
+  return fail;
 }
 
 int
@@ -719,5 +730,6 @@ main (int argc, char **argv)
   /* Initialize the hash structure for inode numbers.  */
   hash_init ();
 
-  RUN_WITH_BIG_STACK_2 (du_files, files, ftw_flags);
+  exit (du_files (files, ftw_flags) || G_fail
+	? EXIT_FAILURE : EXIT_SUCCESS);
 }
