@@ -2,7 +2,7 @@
 
 /* Modified to run with the GNU shell by bfox. */
 
-/* Copyright (C) 1987-2002 Free Software Foundation, Inc.
+/* Copyright (C) 1987-2003 Free Software Foundation, Inc.
 
    This file is part of GNU Bash, the Bourne Again SHell.
 
@@ -39,8 +39,8 @@
 # include "filecntl.h"
 #else /* TEST_STANDALONE */
 # include "system.h"
-# include "group-member.h"
 # include "error.h"
+# include "euidaccess.h"
 # if !defined (S_IXUGO)
 #  define S_IXUGO 0111
 # endif /* S_IXUGO */
@@ -135,55 +135,45 @@ test_syntax_error (char const *format, char const *arg)
   test_exit (SHELL_BOOLEAN (FALSE));
 }
 
-/* A wrapper for stat () which disallows pathnames that are empty strings. */
+#if HAVE_SETREUID && HAVE_SETREGID
+/* Do the same thing access(2) does, but use the effective uid and gid.  */
+
 static int
-test_stat (char *path, struct stat *finfo)
+eaccess (char const *file, int mode)
 {
-  if (*path == '\0')
+  static int have_ids;
+  static uid_t uid, euid;
+  static gid_t gid, egid;
+  int result;
+
+  if (have_ids == 0)
     {
-      errno = ENOENT;
-      return (-1);
-    }
-  return (stat (path, finfo));
-}
-
-/* Do the same thing access(2) does, but use the effective uid and gid,
-   and don't make the mistake of telling root that any file is executable.
-   But this loses when the containing filesystem is mounted e.g. read-only.  */
-static int
-eaccess (char *path, int mode)
-{
-  struct stat st;
-  static uid_t euid = -1;
-
-  if (test_stat (path, &st) < 0)
-    return (-1);
-
-  if (euid == (uid_t) -1)
-    euid = geteuid ();
-
-  if (euid == 0)
-    {
-      /* Root can read or write any file. */
-      if (mode != X_OK)
-	return (0);
-
-      /* Root can execute any file that has any one of the execute
-	 bits set. */
-      if (st.st_mode & S_IXUGO)
-	return (0);
+      have_ids = 1;
+      uid = getuid ();
+      gid = getgid ();
+      euid = geteuid ();
+      egid = getegid ();
     }
 
-  if (st.st_uid == euid)        /* owner */
-    mode <<= 6;
-  else if (group_member (st.st_gid))
-    mode <<= 3;
+  /* Set the real user and group IDs to the effective ones.  */
+  if (uid != euid)
+    setreuid (euid, uid);
+  if (gid != egid)
+    setregid (egid, gid);
 
-  if (st.st_mode & mode)
-    return (0);
+  result = access (file, mode);
 
-  return (-1);
+  /* Restore them.  */
+  if (uid != euid)
+    setreuid (uid, euid);
+  if (gid != egid)
+    setregid (gid, egid);
+
+  return result;
 }
+#else
+# define eaccess(F, M) euidaccess (F, M)
+#endif
 
 /* Increment our position in the argument list.  Check that we're not
    past the end of the argument list.  This check is supressed if the
@@ -298,7 +288,7 @@ static int
 age_of (char *filename, time_t *age)
 {
   struct stat finfo;
-  int r = test_stat (filename, &finfo);
+  int r = stat (filename, &finfo);
   if (r == 0)
     *age = finfo.st_mtime;
   return r;
@@ -640,7 +630,7 @@ unary_operator (void)
     case 'a':			/* file exists in the file system? */
     case 'e':
       unary_advance ();
-      value = -1 != test_stat (argv[pos - 1], &stat_buf);
+      value = -1 != stat (argv[pos - 1], &stat_buf);
       return (TRUE == value);
 
     case 'r':			/* file is readable? */
@@ -660,21 +650,21 @@ unary_operator (void)
 
     case 'O':			/* File is owned by you? */
       unary_advance ();
-      if (test_stat (argv[pos - 1], &stat_buf) < 0)
+      if (stat (argv[pos - 1], &stat_buf) < 0)
 	return (FALSE);
 
       return (TRUE == (geteuid () == stat_buf.st_uid));
 
     case 'G':			/* File is owned by your group? */
       unary_advance ();
-      if (test_stat (argv[pos - 1], &stat_buf) < 0)
+      if (stat (argv[pos - 1], &stat_buf) < 0)
 	return (FALSE);
 
       return (TRUE == (getegid () == stat_buf.st_gid));
 
     case 'f':			/* File is a file? */
       unary_advance ();
-      if (test_stat (argv[pos - 1], &stat_buf) < 0)
+      if (stat (argv[pos - 1], &stat_buf) < 0)
 	return (FALSE);
 
       /* Under POSIX, -f is true if the given file exists
@@ -684,14 +674,14 @@ unary_operator (void)
 
     case 'd':			/* File is a directory? */
       unary_advance ();
-      if (test_stat (argv[pos - 1], &stat_buf) < 0)
+      if (stat (argv[pos - 1], &stat_buf) < 0)
 	return (FALSE);
 
       return (TRUE == (S_ISDIR (stat_buf.st_mode)));
 
     case 's':			/* File has something in it? */
       unary_advance ();
-      if (test_stat (argv[pos - 1], &stat_buf) < 0)
+      if (stat (argv[pos - 1], &stat_buf) < 0)
 	return (FALSE);
 
       return (TRUE == (stat_buf.st_size > (off_t) 0));
@@ -702,7 +692,7 @@ unary_operator (void)
 #else
       unary_advance ();
 
-      if (test_stat (argv[pos - 1], &stat_buf) < 0)
+      if (stat (argv[pos - 1], &stat_buf) < 0)
 	return (FALSE);
 
       return (TRUE == (S_ISSOCK (stat_buf.st_mode)));
@@ -710,14 +700,14 @@ unary_operator (void)
 
     case 'c':			/* File is character special? */
       unary_advance ();
-      if (test_stat (argv[pos - 1], &stat_buf) < 0)
+      if (stat (argv[pos - 1], &stat_buf) < 0)
 	return (FALSE);
 
       return (TRUE == (S_ISCHR (stat_buf.st_mode)));
 
     case 'b':			/* File is block special? */
       unary_advance ();
-      if (test_stat (argv[pos - 1], &stat_buf) < 0)
+      if (stat (argv[pos - 1], &stat_buf) < 0)
 	return (FALSE);
 
       return (TRUE == (S_ISBLK (stat_buf.st_mode)));
@@ -727,7 +717,7 @@ unary_operator (void)
 #ifndef S_ISFIFO
       return (FALSE);
 #else
-      if (test_stat (argv[pos - 1], &stat_buf) < 0)
+      if (stat (argv[pos - 1], &stat_buf) < 0)
 	return (FALSE);
       return (TRUE == (S_ISFIFO (stat_buf.st_mode)));
 #endif				/* S_ISFIFO */
@@ -753,7 +743,7 @@ unary_operator (void)
 #ifndef S_ISUID
       return (FALSE);
 #else
-      if (test_stat (argv[pos - 1], &stat_buf) < 0)
+      if (stat (argv[pos - 1], &stat_buf) < 0)
 	return (FALSE);
 
       return (TRUE == (0 != (stat_buf.st_mode & S_ISUID)));
@@ -764,7 +754,7 @@ unary_operator (void)
 #ifndef S_ISGID
       return (FALSE);
 #else
-      if (test_stat (argv[pos - 1], &stat_buf) < 0)
+      if (stat (argv[pos - 1], &stat_buf) < 0)
 	return (FALSE);
 
       return (TRUE == (0 != (stat_buf.st_mode & S_ISGID)));
@@ -772,7 +762,7 @@ unary_operator (void)
 
     case 'k':			/* File has sticky bit set? */
       unary_advance ();
-      if (test_stat (argv[pos - 1], &stat_buf) < 0)
+      if (stat (argv[pos - 1], &stat_buf) < 0)
 	return (FALSE);
 #ifndef S_ISVTX
       /* This is not Posix, and is not defined on some Posix systems. */
